@@ -1,5 +1,7 @@
+from .api_jwk import PyJWK, PyJWKSet
 from .api_jws import (
     PyJWS,
+    get_algorithm_by_name,
     get_unverified_header,
     register_algorithm,
     unregister_algorithm,
@@ -13,6 +15,7 @@ from .exceptions import (
     InvalidAudienceError,
     InvalidIssuedAtError,
     InvalidIssuerError,
+    InvalidKeyError,
     InvalidSignatureError,
     InvalidTokenError,
     MissingRequiredClaimError,
@@ -23,30 +26,33 @@ from .exceptions import (
 )
 from .jwks_client import PyJWKClient
 
-__version__ = "2.0.1"
+__version__ = "2.6.0"
 
 __title__ = "PyJWT"
 __description__ = "JSON Web Token implementation in Python"
 __url__ = "https://pyjwt.readthedocs.io"
 __uri__ = __url__
-__doc__ = __description__ + " <" + __uri__ + ">"
+__doc__ = f"{__description__} <{__uri__}>"
 
 __author__ = "José Padilla"
 __email__ = "hello@jpadilla.com"
 
 __license__ = "MIT"
-__copyright__ = "Copyright 2015-2020 José Padilla"
+__copyright__ = "Copyright 2015-2022 José Padilla"
 
 
 __all__ = [
     "PyJWS",
     "PyJWT",
     "PyJWKClient",
+    "PyJWK",
+    "PyJWKSet",
     "decode",
     "encode",
     "get_unverified_header",
     "register_algorithm",
     "unregister_algorithm",
+    "get_algorithm_by_name",
     # Exceptions
     "DecodeError",
     "ExpiredSignatureError",
@@ -55,6 +61,7 @@ __all__ = [
     "InvalidAudienceError",
     "InvalidIssuedAtError",
     "InvalidIssuerError",
+    "InvalidKeyError",
     "InvalidSignatureError",
     "InvalidTokenError",
     "MissingRequiredClaimError",
